using System;
using System.Collections;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.PortalEngine;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.PortalControls;
using CMS.DirectoryUtilities;
using CMS.SettingsProvider;
using CMS.URLRewritingEngine;

/// <summary>
/// Base class for the portal pages
/// </summary>
public class PortalPage : System.Web.UI.Page
{
    /// <summary>
    /// Generic body class - contains the base body css class
    /// </summary>
    protected string mBodyClass = "LTR";

    /// <summary>
    /// Page title
    /// </summary>
    protected string mTitle = null;

    /// <summary>
    /// Page CSS file link
    /// </summary>
    protected string mCssFile = null;

    /// <summary>
    /// Page keywords
    /// </summary>
    protected string mKeyWords = null;

    /// <summary>
    /// Page description
    /// </summary>
    protected string mDescription = null;

    /// <summary>
    /// Extended page tags
    /// </summary>
    protected string mExtendedTags = null;


    Panel pnlToolbarHeight = null;
    Panel pnlLowToolbarHeight = null;


    /// <summary>
    /// If false, default layout rendering is disabled
    /// </summary>
    protected bool renderLayout = true;


    /// Page stylesheet
    protected CssStylesheetInfo mStyleSheet = null;

    /// Current page
    protected PageInfo mCurrentPage = null;

    /// Current site
    protected CurrentSiteInfo mCurrentSite = null;

    /// <summary>
    /// Page portal manager
    /// </summary>
    protected CMSPortalManager manager = null;


    /// <summary>
    /// List of the toolbar controls
    /// </summary>
    private ArrayList ToolbarControls = null;


    /// <summary>
    /// Constructor
    /// </summary>
    public PortalPage()
    {
        this.Load += new EventHandler(PortalPage_Load);
        this.Init += new EventHandler(PortalPage_Init);
        this.PreInit += new EventHandler(PortalPage_PreInit);
        this.PreRender += new EventHandler(PortalPage_PreRender);
    }


    void PortalPage_PreInit(object sender, EventArgs e)
    {
        mCurrentSite = CMSContext.CurrentSite;
        if (mCurrentSite != null)
        {
            mDescription = SettingsKeyProvider.GetStringValue(mCurrentSite.SiteName + ".CMSPageDescriptionPrefix");
            mKeyWords = SettingsKeyProvider.GetStringValue(mCurrentSite.SiteName + ".CMSPageKeyWordsPrefix");
            mTitle = SettingsKeyProvider.GetStringValue(mCurrentSite.SiteName + ".CMSPageTitlePrefix");
        }

        mCurrentPage = CMSContext.CurrentPageInfo;
        if (mCurrentPage != null)
        {
            URLRewriter.CheckSecuredAreas(mCurrentPage, false);

            mKeyWords += mCurrentPage.DocumentPageKeyWords;
            mDescription += mCurrentPage.DocumentPageDescription;
            //mCssFile = DataHelper.GetNotEmpty(currentPage.
            mTitle += mCurrentPage.DocumentPageTitle;
            if (mCurrentPage.DocumentStylesheetID > 0)
            {
                mStyleSheet = CssStylesheetInfoProvider.GetCssStylesheetInfo(mCurrentPage.DocumentStylesheetID);
            }
            // If not found, get default stylesheet from the current site
            if ((mStyleSheet == null) && (mCurrentSite.SiteDefaultStylesheetID > 0))
            {
                mStyleSheet = CssStylesheetInfoProvider.GetCssStylesheetInfo(mCurrentSite.SiteDefaultStylesheetID);
            }
            // If stylesheet found, get the URL
            if (mStyleSheet != null)
            {
                mCssFile = CssStylesheetInfoProvider.GetStylesheetUrl(mStyleSheet.StylesheetName);
                if (Directory.Exists(Server.MapPath("~/App_Themes/") + mStyleSheet.StylesheetName))
                {
                    this.Theme = mStyleSheet.StylesheetName;
                }
            }
            //else
            //{
            //    mCssFile = ResolveUrl("~/main.css");
            //}
        }
    }


    void PortalPage_Init(object sender, EventArgs e)
    {
        manager = PortalHelper.FindManager(this.Form);

        if (manager != null)
        {
            int managerIndex = this.Form.Controls.IndexOf(manager);

            PageInfo currentPage = CMSContext.CurrentPageInfo;
            if (currentPage != null)
            {
                // Create the layout
                if (renderLayout)
                {
                    bool isMenuItem = TreePathUtils.IsMenuItemType(currentPage.ClassName);

                    if ((isMenuItem && CMSContext.CurrentUser.MenuItemViewMode == ViewModeEnum.Edit) || (!isMenuItem && CMSContext.CurrentUser.ViewMode == ViewModeEnum.Edit))
                    {
                        this.ToolbarControls = new ArrayList();

                        // Toolbar container start
                        this.Form.Controls.AddAt(managerIndex, new LiteralControl("<div class=\"PortalEditorToolbar\">"));
                        managerIndex += 1;

                        // Toolbar area
                        LiteralControl tc = new LiteralControl("<div id=\"FCKToolbar\" style=\"height: 76px;\"></div>");
                        this.Form.Controls.AddAt(managerIndex, tc);
                        this.ToolbarControls.Add(tc);
                        managerIndex += 1;

                        // Toolbar height
                        pnlToolbarHeight = new Panel();
                        pnlToolbarHeight.Controls.Add(new LiteralControl("&nbsp;"));
                        pnlToolbarHeight.CssClass = "PortalToolbarHeight";
                        pnlToolbarHeight.EnableViewState = false;
                        this.Form.Controls.AddAt(managerIndex + 1, pnlToolbarHeight);
                        this.ToolbarControls.Add(pnlToolbarHeight);

                        // Low toolbar height
                        pnlLowToolbarHeight = new Panel();
                        pnlLowToolbarHeight.Controls.Add(new LiteralControl("&nbsp;"));
                        pnlLowToolbarHeight.CssClass = "PortalLowToolbarHeight";
                        pnlLowToolbarHeight.EnableViewState = false;
                        pnlLowToolbarHeight.Visible = false;
                        this.Form.Controls.AddAt(managerIndex + 1, pnlLowToolbarHeight);

                        // Content area start
                        this.Form.Controls.AddAt(managerIndex + 1, new LiteralControl("<div class=\"PortalEditArea\">"));

                        // Toolbar container end
                        tc = new LiteralControl("</div>");
                        this.Form.Controls.AddAt(managerIndex + 1, tc);
                        //this.ToolbarControls.Add(tc);

                        // Content area end
                        this.Form.Controls.Add(new LiteralControl("</div>"));
                    }
                    else
                    {
                        //this.Form.Controls.AddAt(0, new LiteralControl("<div class=\"PortalContentArea\">"));
                        //this.Form.Controls.Add(new LiteralControl("</div>"));
                    }
                }
            }
        }
    }


    /// <summary>
    /// Load event handler
    /// </summary>
    void PortalPage_Load(object sender, EventArgs e)
    {
        Response.Cache.SetNoStore();

        if (CultureHelper.IsPreferredCultureRTL())
        {
            if (this.Header != null)
            {
                this.mExtendedTags += "<style type=\"text/css\">* { direction: rtl; }</style>";
                mBodyClass = "RTL";
            }
        }

        // Initialize the design styles
        bool useDesignStyles = false;
        bool useEditStyle = false;
        if (TreePathUtils.IsMenuItemType(mCurrentPage.ClassName))
        {
            useDesignStyles = (CMSContext.CurrentUser.MenuItemViewMode != ViewModeEnum.LiveSite);
            useEditStyle = (CMSContext.CurrentUser.MenuItemViewMode == ViewModeEnum.Edit);
        }
        else
        {
            useDesignStyles = (CMSContext.CurrentUser.ViewMode != ViewModeEnum.LiveSite);
            useEditStyle = (CMSContext.CurrentUser.ViewMode == ViewModeEnum.Edit);
        }

        if (useDesignStyles)
        {
            this.mExtendedTags += HTMLHelper.GetCSSFileLink(ResolveUrl("~/App_Themes/" + DataHelper.GetNotEmpty(this.Theme, "Default") + "/DesignMode.css"));
        }

        // Edit / Design body style
        if (useEditStyle)
        {
            this.mExtendedTags += "<style type=\"text/css\"> \n" +
                                    "html, body { margin: 0px; padding: 0px; height: 100%; width: 100%; overflow: hidden; } \n" +
                //".PortalContentArea { height: 100%; width: 100%; position: absolute; z-index: 1; overflow: auto; } \n" +
                                  "</style>";
        }
        else if (useDesignStyles)
        {
            this.mExtendedTags += "<style type=\"text/css\"> \n" +
                                    "html, body {  margin: 0px; padding: 0px; } \n" +
                                  "</style>";
        }
    }


    void PortalPage_PreRender(object sender, EventArgs e)
    {
        if (((manager == null) || (!manager.UsesHtmlEditor(null))) && (ToolbarControls != null))
        {
            foreach (Control tc in this.ToolbarControls)
            {
                tc.Visible = false;
            }
            pnlLowToolbarHeight.Visible = true;
        }
    }

}
