using System.Web;
using System.IO;
using System.Web.SessionState;
using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Drawing;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.Configuration;

using CMS.GlobalEventHelper;
using CMS.URLRewritingEngine;
using CMS.CMSHelper;
using CMS.CMSOutputFilter;
using CMS.Scheduler;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.EventLog;
using CMS.EmailEngine;
using CMS.GlobalHelper;

public class Global : System.Web.HttpApplication
{
    static SchedulingTimer st = null;
    static bool schedulerIsRunning = false;

    #region '" Component Designer Generated Code "'

    public Global()
        : base()
    {
        // This call is required by the Component Designer.
        InitializeComponent();
    }

    // Required by the Component Designer
    private System.ComponentModel.IContainer components;

    // NOTE: The following procedure is required by the Component Designer
    // It can be modified using the Component Designer.
    // Do not modify it using the code editor.
    [System.Diagnostics.DebuggerStepThrough()]
    private void InitializeComponent()
    {
        components = new System.ComponentModel.Container();
        // events handled by Application_AcquireRequestState
        base.AcquireRequestState += new System.EventHandler(Application_AcquireRequestState);
    }

    #endregion

    public void Application_Start(object sender, EventArgs e)
    {
        // Try to run scheduler
        if (InstallerFunctions.ConnectionStringIsSet())
        {
            st = SchedulingTimer.CreateTimer();
            schedulerIsRunning = (st == null ? false : true);
        }
    }


    public void Session_Start(object sender, EventArgs e)
    {
    }


    public void Application_BeginRequest(object sender, EventArgs e)
    {
        // Check if Database installation needed
        if (InstallerFunctions.InstallRedirect())
        {
            return;
        }

        // Rewrite the path to get to the proper page
        switch (URLRewriter.RewriteUrl())
        {
            case URLRewritingResultEnum.PathRewritten:
                // Apply output filter
                Response.Filter = new CMS.CMSOutputFilter.OutputFilter(Response.Filter);
                break;
        
        }

        // Run scheduler
        if (!schedulerIsRunning)
        {
            if (InstallerFunctions.ConnectionStringIsSet())
            {
                st = SchedulingTimer.CreateTimer();
                schedulerIsRunning = (st == null ? false : true);
            }
        }
    }


    public void Application_AcquireRequestState(object sender, EventArgs e)
    {

        // Set the UI culture
        if ((HttpContext.Current.Session != null) && (InstallerFunctions.ConnectionStringIsSet()))
        {
            
            URLRewriter.CheckSecuredAreas(CMSContext.CurrentPageInfo, true);
            
            // Set the culture
            CurrentUserInfo ui = CMSContext.CurrentUser;
            if (ui != null)
            {
                System.Threading.Thread.CurrentThread.CurrentCulture = ui.PreferredUICultureInfo;
                System.Threading.Thread.CurrentThread.CurrentUICulture = ui.PreferredUICultureInfo;
            }
        }
    }


    public void Application_AuthenticateRequest(object sender, EventArgs e)
    {
    }


    public void Application_AuthorizeRequest(object sender, EventArgs e)
    {
    }


    public void Application_Error(object sender, EventArgs e)
    {
        // Run custom exception event handler
        if (EventHelper.UseCustomHandlers())
        {
            EventHelper.GetExceptionHandler().OnException(HttpContext.Current.Server.GetLastError());
        }

        Exception ex = HttpContext.Current.Server.GetLastError();
        // Write error to Event log
        try
        {                       
            EventLogProvider eProvider = new EventLogProvider();
            eProvider.LogEvent("E", DateTime.Now, "Application_Error", "EXCEPTION", CMSContext.CurrentUser != null ? CMSContext.CurrentUser.UserID : 0, CMSContext.CurrentUser != null ? CMSContext.CurrentUser.UserName : "", CMSContext.CurrentDocument != null ? CMSContext.CurrentDocument.NodeID : 0, CMSContext.CurrentDocument != null ? CMSContext.CurrentDocument.DocumentName : "", HttpContext.Current.Request.UserHostAddress, "EXCEPTION MESSAGE: " + ex.Message + "; STACK TRACE: " + ex.StackTrace, CMSContext.CurrentSite != null ? CMSContext.CurrentSite.SiteID : 0, HttpContext.Current.Request.Url.AbsoluteUri);           
        }
        catch
        {
            // can't write to log, do not process any code
        }
        // Send e-mail
        try
        {
            Configuration config = WebConfigurationManager.OpenWebConfiguration("~");
            // if key exists
            if ((config.AppSettings.Settings["CMSSendErrorsToEmail"] != null) && (config.AppSettings.Settings["CMSSendErrorsFromEmail"] != null))
            {
                // if values are not empty
                if ((ValidationHelper.GetString(config.AppSettings.Settings["CMSSendErrorsFromEmail"].Value, "") != "") && (ValidationHelper.GetString(config.AppSettings.Settings["CMSSendErrorsToEmail"].Value, "") != ""))
                {
                    EmailMessage msg = new EmailMessage();
                    msg.From = config.AppSettings.Settings["CMSSendErrorsFromEmail"].Value;
                    msg.Recipients = config.AppSettings.Settings["CMSSendErrorsToEmail"].Value;
                    msg.Subject = "Web site exception:" + HttpContext.Current.Request.Url.AbsoluteUri;
                    msg.Body = "Error message: " + ex.Message + "\n Stack trace: " + ex.StackTrace + "\n URL: " + HttpContext.Current.Request.Url.AbsoluteUri + "\n Date and time: " + DateTime.Now.ToString() + "\n IP adress: " + HttpContext.Current.Request.UserHostAddress + "\n User name: " + (CMSContext.CurrentUser != null ? CMSContext.CurrentUser.UserName : "");
                    EmailSender.SendEmail(msg);
                }
            }
        }
        catch
        {
            // can't send e-mail, do not process any code
        }
    }


    public void Session_End(object sender, EventArgs e)
    {
    }


    public void Application_End(object sender, EventArgs e)
    {
    }

}

