using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.ExtendedControls;
using CMS.WorkflowEngine;
using CMS.CMSHelper;

public partial class CMSDesk_Content_Properties_general : CMSDeskPage
{
    int nodeId = 0;
    protected string mSave = null;
    string imagesUrl = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        imagesUrl = ResolveUrl("~/App_Themes/" + this.Page.Theme + "/Images/CMSDesk/Content/");

        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        this.valAlias.ErrorMessage = ResHelper.GetString("GeneralProperties.RequiresAlias");

        this.lblAlias.Text = ResHelper.GetString("GeneralProperties.Alias");
        this.lblUrlPath.Text = ResHelper.GetString("GeneralProperties.UrlPath");

        this.lblOther.Text = ResHelper.GetString("GeneralProperties.Other");
        this.lblNameTitle.Text = ResHelper.GetString("GeneralProperties.Name");
        this.lblNamePathTitle.Text = ResHelper.GetString("GeneralProperties.NamePath");
        this.lblAliasPathTitle.Text = ResHelper.GetString("GeneralProperties.AliasPath");
        this.lblTypeTitle.Text = ResHelper.GetString("GeneralProperties.Type");
        this.lblNodeIDTitle.Text = ResHelper.GetString("GeneralProperties.NodeID");
        this.lblLastModifiedByTitle.Text = ResHelper.GetString("GeneralProperties.LastModifiedBy");
        this.lblLastModifiedTitle.Text = ResHelper.GetString("GeneralProperties.LastModified");
        this.lblLiveURLTitle.Text = ResHelper.GetString("GeneralProperties.LiveURL");
        this.lblGUIDTitle.Text = ResHelper.GetString("GeneralProperties.GUID");
        this.lblCultureTitle.Text = ResHelper.GetString("GeneralProperties.Culture");
        this.lblCreatedByTitle.Text = ResHelper.GetString("GeneralProperties.CreatedBy");
        this.lblCreatedTitle.Text = ResHelper.GetString("GeneralProperties.Created");
        this.chkCustomUrl.Text = ResHelper.GetString("GeneralProperties.UseCustomUrlPath");

        this.imgSave.ImageUrl = imagesUrl + "save.gif";
        mSave = ResHelper.GetString("EditMenu.IconSave");

        if (!this.IsPostBack)
        {
            ReloadData();
        }
    }


    private void ReloadData()
    {
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        CMS.TreeEngine.TreeNode node = null;
        node = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);
        //node = tree.SelectSingleNode(nodeId);
        if (node != null)
        {
            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {                
                CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }
            else
            {
                // Check modify permissions
                if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
                {
                    // disable form editing                                                            
                    DisableFormEditing();

                    // show access denied message
                    lblInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
                }
                
                this.txtAlias.Text = node.NodeAlias;
                this.txtUrlPath.Text = node.DocumentUrlPath;
                this.chkCustomUrl.Checked = !node.DocumentUseNamePathForUrlPath;

                if (node.NodeClassName.ToLower() == "cms.root")
                {
                    DisableFormEditing();
                }
                else
                {
                    this.txtUrlPath.Enabled = this.chkCustomUrl.Checked;
                }

                this.lblName.Text = node.DocumentName;
                this.lblNamePath.Text = Convert.ToString(node.GetValue("DocumentNamePath"));
                this.lblAliasPath.Text = Convert.ToString(node.NodeAliasPath);
                this.lblType.Text = DataClassInfoProvider.GetDataClass(node.NodeClassName).ClassDisplayName;
                this.lblNodeID.Text = Convert.ToString(node.NodeID);
                int uid = ValidationHelper.GetInteger(node.GetValue("DocumentModifiedByUserId"), 0);
                if (uid > 0)
                {
                    this.lblLastModifiedBy.Text = UserInfoProvider.GetUserInfo(uid).FullName;
                }
                this.lblLastModified.Text = Convert.ToString(node.GetValue("DocumentModifiedWhen"));

                string liveUrl = CMSContext.GetUrl(node.NodeAliasPath, node.DocumentUrlPath);
                this.lnkLiveURL.Text = AbsoluteUrl(liveUrl);
                this.lnkLiveURL.NavigateUrl = liveUrl;

                this.lblGUID.Text = Convert.ToString(node.NodeGUID);

                CultureInfo ci = CultureInfoProvider.GetCultureInfo(node.DocumentCulture);
                if (ci != null)
                {
                    this.lblCulture.Text = ci.CultureName;
                }
                else
                {
                    this.lblCulture.Text = node.DocumentCulture;
                }

                uid = ValidationHelper.GetInteger(node.GetValue("DocumentCreatedByUserId"), 0);
                if (uid > 0)
                {
                    this.lblCreatedBy.Text = UserInfoProvider.GetUserInfo(uid).FullName;
                }
                this.lblCreated.Text = Convert.ToString(node.GetValue("DocumentCreatedWhen"));

                if ( !this.chkCustomUrl.Checked )
                {
                    txtUrlPath.Enabled = false;
                }
            }
        }
    }


    protected void chkCustomUrl_CheckedChanged(object sender, EventArgs e)
    {
        this.txtUrlPath.Enabled = this.chkCustomUrl.Checked;
        if (!this.chkCustomUrl.Checked)
        {
            txtUrlPath.Text = "";
        }
    }


    protected void lnkSave_Click(object sender, EventArgs e)
    {
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, CMSContext.CurrentUser.PreferredCultureCode);
        if (node != null)
        {
            node.NodeAlias = this.txtAlias.Text.Trim();
            node.DocumentUrlPath = this.txtUrlPath.Text.Trim();
            node.DocumentUseNamePathForUrlPath = !this.chkCustomUrl.Checked;

            node.Update();

            this.lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            ReloadData();
        }
    }


    /// <summary>
    /// Disables form editing.
    /// </summary>
    protected void DisableFormEditing()
    {
        // disable form editing
        this.txtAlias.Enabled = false;
        this.txtUrlPath.Enabled = false;
        this.chkCustomUrl.Enabled = false;
        this.lblAlias.Enabled = false;
        this.lblUrlPath.Enabled = false;        

        // disable 'save button'
        this.lnkSave.Enabled = false;
        this.lnkSave.CssClass = "MenuItemEditDisabled";
        this.imgSave.ImageUrl = imagesUrl + "savedisabled.gif";        
               
    }
}
