using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.skmMenuControl;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SiteProvider;

public partial class CMSDesk_Content_menu : CMSDeskPage
{
    protected int selectedNodeId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        CurrentUserInfo currentUser = CMSContext.CurrentUser;
        CurrentSiteInfo currentSite = CMSContext.CurrentSite;

        // Register the dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        this.requestPageUrl.Value = ResolveUrl("request.aspx");
        this.ltlScript.Text = ScriptHelper.GetScript("var contentDir = '" + ResolveUrl("~/CMSDesk/Content/") + "';");

        CMS.skmMenuControl.MenuItem newItem = null;
        string imagesUrl = ResolveUrl("~/App_Themes/" + Theme + "/Images/CMSDesk/Menu/");
        this.ltlData.Text += "<input type=\"hidden\" id=\"imagesUrl\" value=\"" + imagesUrl + "\" />";
        this.lblLanguage.Text = ResHelper.GetString("ContentMenu.Language");

        DataSet ds = CultureInfoProvider.GetSiteCultures(currentSite.SiteName);
        this.dropLanguage.DataSource = ds;
        this.dropLanguage.DataBind();

        // Check (and ensure) the proper content culture
        if (!CultureInfoProvider.IsCultureOnSite(currentUser.PreferredCultureCode, currentSite.SiteName))
        {
            string defaultCulture = CultureHelper.GetDefaultCulture(currentSite.SiteName);
            if (CultureInfoProvider.IsCultureOnSite(defaultCulture, currentSite.SiteName))
            {
                currentUser.PreferredCultureCode = defaultCulture;
                AddScript("parent.window.location.replace(parent.window.location);");
            }
            else
            {
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    currentUser.PreferredCultureCode = ValidationHelper.GetString(ds.Tables[0].Rows[0]["CultureCode"], "en-us");
                    AddScript("parent.window.location.replace(parent.window.location);");
                }
            }
        }

        try
        {
            this.dropLanguage.SelectedValue = currentUser.PreferredCultureCode;
        }
        catch
        {
        }

        currentUser.PreferredCultureCode = this.dropLanguage.SelectedValue;
        if (this.dropLanguage.Items.Count < 2)
        {
            this.pnlLang.Visible = false;
            this.pnlSep.Visible = false;
        }

        // Setup selected node ID
        selectedNodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        // Create menu with basic operations
        menuLeft.Items.Clear();

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.JavascriptCommand = "NewItem();";
        newItem.ToolTip = ResHelper.GetString("ContentMenu.New");
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = "<br/>" + ResHelper.GetString("ContentMenu.IconNew");
        newItem.Image = imagesUrl + "new.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemLeftOver";
        newItem.CssClass = "MenuItemLeft";
        menuLeft.Items.Add(newItem);

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.JavascriptCommand = "DeleteItem();";
        newItem.ToolTip = ResHelper.GetString("ContentMenu.Delete");
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = "<br/>" + ResHelper.GetString("ContentMenu.IconDelete");
        newItem.Image = imagesUrl + "delete.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemLeftOver";
        newItem.CssClass = "MenuItemLeft";
        menuLeft.Items.Add(newItem);
        
        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.ToolTip = ResHelper.GetString("ContentMenu.CopyItem");
        newItem.JavascriptCommand = "CopyItem();";
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = "<br/>" + ResHelper.GetString("ContentMenu.IconCopy");
        newItem.Image = imagesUrl + "copy.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemLeftOver";
        newItem.CssClass = "MenuItemLeft";
        menuLeft.Items.Add(newItem);

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.ToolTip = ResHelper.GetString("ContentMenu.Move");
        newItem.JavascriptCommand = "MoveItem();";
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = "<br/>" + ResHelper.GetString("ContentMenu.IconMove");
        newItem.Image = imagesUrl + "move.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemLeftOver";
        newItem.CssClass = "MenuItemLeft";
        menuLeft.Items.Add(newItem);

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.ToolTip = ResHelper.GetString("ContentMenu.MoveUp");
        newItem.JavascriptCommand = "MoveUp();";
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = "<br/>" + ResHelper.GetString("ContentMenu.IconMoveUp");
        newItem.Image = imagesUrl + "up.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemLeftOver";
        newItem.CssClass = "MenuItemLeft";
        menuLeft.Items.Add(newItem);

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.ToolTip = ResHelper.GetString("ContentMenu.MoveDown");
        newItem.JavascriptCommand = "MoveDown();";
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = "<br/>" + ResHelper.GetString("ContentMenu.IconMoveDown");
        newItem.Image = imagesUrl + "down.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemLeftOver";
        newItem.CssClass = "MenuItemLeft";
        menuLeft.Items.Add(newItem);

        menuLeft.Cursor = CMS.skmMenuControl.MouseCursor.Pointer;
        menuLeft.Layout = CMS.skmMenuControl.MenuLayout.Horizontal;
        //menuLeft.CssClass = "ContentMenu"; 
        
        // Create the mode menu
        menuRight.Items.Clear();

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.ToolTip = ResHelper.GetString("ContentMenu.Edit");
        newItem.JavascriptCommand = "SetMode('edit');";
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = ResHelper.GetString("ContentMenu.IconEdit");
        newItem.Image = imagesUrl + "edit.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemRightOver";
        newItem.CssClass = "MenuItemRight";
        menuRight.Items.Add(newItem);

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.ToolTip = ResHelper.GetString("ContentMenu.Preview");
        newItem.JavascriptCommand = "SetMode('preview');";
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = ResHelper.GetString("ContentMenu.IconPreview");
        newItem.Image = imagesUrl + "preview.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemRightOver";
        newItem.CssClass = "MenuItemRight";
        menuRight.Items.Add(newItem);

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.ToolTip = ResHelper.GetString("ContentMenu.LiveSite");
        newItem.JavascriptCommand = "SetMode('livesite');";
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = ResHelper.GetString("ContentMenu.IconLive");
        newItem.Image = imagesUrl + "live.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemRightOver";
        newItem.CssClass = "MenuItemRight";
        menuRight.Items.Add(newItem);

        newItem = new CMS.skmMenuControl.MenuItem();
        newItem.ToolTip = ResHelper.GetString("ContentMenu.Listing");
        newItem.JavascriptCommand = "SetMode('listing');";
        newItem.ImageAltText = newItem.ToolTip;
        newItem.Text = ResHelper.GetString("ContentMenu.IconListing");
        newItem.Image = imagesUrl + "listing.gif";
        newItem.MouseOverImage = newItem.Image;
        newItem.MouseOverCssClass = "MenuItemRightOver";
        newItem.CssClass = "MenuItemRight";
        menuRight.Items.Add(newItem);

        menuRight.Cursor = CMS.skmMenuControl.MouseCursor.Pointer;
        menuRight.Layout = CMS.skmMenuControl.MenuLayout.Horizontal;

        int selectedActionIndex = 0;
        string action = ValidationHelper.GetString(Request.QueryString["action"], "edit").ToLower();
        switch (action)
        {
            case "edit":
                selectedActionIndex = 0;
                break;
            case "preview":
                selectedActionIndex = 1;
                break;
            case "livesite":
                selectedActionIndex = 2;
                break;
            case "listing":
                selectedActionIndex = 3;
                break;
        }

        menuRight.HighlightedItemIndexByDefault = selectedActionIndex;

        this.dropLanguage.Attributes.Add("onchange", "ChangeLanguage(this);");
    }

    /// <summary>
    /// Adds the script to the output request window
    /// </summary>
    /// <param name="script">Script to add</param>
    private void AddScript(string script)
    {
        this.ltlScript.Text += ScriptHelper.GetScript(script);
    }

}
