using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.PortalEngine;

public partial class CMSDesk_PortalEngine_SaveNewPageTemplate : CMSDeskPage
{
    protected int pageTemplateId = 0;
    protected PageTemplateInfo pt = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        pageTemplateId = ValidationHelper.GetInteger(Request.QueryString["templateid"], 0);
        if (pageTemplateId > 0) pt = PageTemplateInfoProvider.GetPageTemplateInfo(pageTemplateId);
        
        PageTitle1.TitleText = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.PageTitle");
        PageTitle1.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/PortalEngine/SaveNewPageTemplate/title.gif";

        lblTemplateDisplayName.Text = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.DisplayName");
        lblTemplateDescription.Text = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.Description");
        lblTemplateCategory.Text = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.Category");
        lblTemplateCodeName.Text = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.CodeName");

        btnOK.Text = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.OK");
        btnCancel.Text = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.Cancel");

        rfvTemplateCategory.ErrorMessage = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.rfvCategoryMsg");
        rfvTemplateDisplayName.ErrorMessage = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.rfvDisplayNameMsg");
        rfvTemplateCodeName.ErrorMessage = ResHelper.GetString("PortalEngine.SaveNewPageTemplate.rfvCodeNameMsg");

        // fills in drpTemplates
        if (!IsPostBack)
        {
            FillDropDownListCategories(0, 0);   // hierarchical list
            if (drpTemplateCategory.Items.Count > 0)
            {
                if (pt != null)
                {
                    drpTemplateCategory.SelectedValue = pt.CategoryID.ToString();
                }
                else
                {
                    drpTemplateCategory.SelectedIndex = 0;
                }
            }
        }
    }


    /// <summary>
    /// Fills existing category names in drop down list, recursive
    /// </summary>
    /// <param name="shift">Sub-category offset in drop down list</param>
    /// <param name="parentCategoryID">ID of parent category</param>
    protected void FillDropDownListCategories(int shift, int parentCategoryID)
    {
        DataSet categories = null;
        if (parentCategoryID == 0)
            shift = 0;
        else
            shift++;

        categories = PageTemplateCategoryInfoProvider.GetDescendantCategories(parentCategoryID);

        if ((categories != null) && (categories.Tables.Count > 0) && (categories.Tables[0].Rows.Count > 0))
        {
            foreach (DataRow dr in categories.Tables[0].Rows)
            {
                if (dr["CategoryDisplayName"].ToString().ToLower() != "ad-hoc")
                {
                    ListItem category = new ListItem();
                    category.Text = string.Empty;
                    for (int i = 0; i < shift; i++)
                        category.Text += "\xA0\xA0\xA0";
                    category.Text += dr["CategoryDisplayName"].ToString();
                    category.Value = dr["CategoryID"].ToString();
                    drpTemplateCategory.Items.Add(category);
                    FillDropDownListCategories(shift, Convert.ToInt32(dr["CategoryID"]));
                }
            }
        }
    }
    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (pageTemplateId > 0)
        {
            if (pt != null)
            {
                if (pt.IsReusable == true)
                {
                    pt = pt.Clone();
                    pt.PageTemplateId = 0;
                }
                pt.CodeName = txtTemplateCodeName.Text;
                pt.DisplayName = txtTemplateDisplayName.Text;
                pt.Description = txtTemplateDescription.Text;
                if (drpTemplateCategory.SelectedIndex > -1)
                {
                    pt.CategoryID = Convert.ToInt32(drpTemplateCategory.SelectedValue);
                }
                pt.IsReusable = true;
                try
                {
                    PageTemplateInfoProvider.SetPageTemplateInfo(pt);
                    if ((Request.QueryString["siteid"] != null) && (Request.QueryString["siteid"] != ""))
                    {
                        PageTemplateInfoProvider.AddPageTemplateToSite(pt.PageTemplateId, Convert.ToInt32(Request.QueryString["siteid"]));
                    }
                    ltlScript.Text = ScriptHelper.GetScript("SelectActualData(" + pt.PageTemplateId.ToString() + ", " + pt.IsPortal.ToString().ToLower() + ", " + pt.IsReusable.ToString().ToLower() + ");");
                }
                catch(Exception ex)
                {
                    lblError.Text = ex.Message;
                }
            }
        }
    }
}
