using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.DirectoryUtilities;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.SettingsProvider;
using CMS.CMSHelper;
using CMS.DataEngine;
using CMS.FileManager;
using CMS.SiteProvider;
using CMS.LicenseProvider;

public partial class CMSDesk_Tools_FileImport_Default : CMSDeskPage
{
    private ListBox files = new ListBox();
    private DataTable dt = new DataTable();
    private ArrayList resultList = new ArrayList();
    private TreeProvider tree;
    protected Hashtable mimes;
    protected string targetAliasPath = "";
    protected string rootPath = "~/cmsimportfiles";

    protected void Page_Load(object sender, EventArgs e)
    {
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.FileImport);
        }
        // Check permissions.
        if (CMSContext.CurrentUser != null)
        {
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.FileImport", "ImportFiles"))
            {
                CMSDeskPage.RedirectToAccessDenied("CMS.FileImport", "ImportFiles");
            }
        }

        PageTitleFileImport.TitleText = ResHelper.GetString("Tools.FileImport.FileImport");
        PageTitleFileImport.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/FileImport/fileimport.gif";
        //if import folder for current site is specified in settings set its path as rootpath
        string keyName = "";
        if ((CMSContext.CurrentSite.SiteName != null) && (CMSContext.CurrentSite.SiteName != ""))
        {
            keyName = CMSContext.CurrentSite.SiteName + "." + "CMSFileImportFolder";
            if ((SettingsKeyProvider.KeyExists(keyName)) && (SettingsKeyProvider.GetValue(keyName) != null) && (SettingsKeyProvider.GetValue(keyName).ToString() != ""))
            {
                rootPath = SettingsKeyProvider.GetValue(keyName).ToString();
            }
        }

        if (!((char.IsLetter(rootPath.ToLower(), 0)) && (rootPath[1] == ':')))
        {
            rootPath = HttpContext.Current.Server.MapPath(rootPath);
        }
        else
        {
            if (rootPath[2] != '\\')
            {
                rootPath = rootPath[0] + ":\\" + rootPath.Substring(2, rootPath.Length - 2);
            }
        }
        
        // Register the dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        tree = new TreeProvider();

        int siteId = 0;
        if (CMSContext.CurrentSite != null)
        {
            siteId = CMSContext.CurrentSite.SiteID;
        }
        //this.lblHeader.Text = ResHelper.GetString("Tools.FileImport.Header");
        ltlChoosePath.Text = "<input class=\"formButton\" onclick=\"modalDialog('../../Content/SelectNodeDialog/default.aspx?action=select&siteid=" + siteId.ToString() + "', 'contentselectnode', 400, 600); return false;\" type=\"button\" value=\"" + ResHelper.GetString("Tools.FileImport.SelectPath") + "\">";
        this.lblTitle.Text = ResHelper.GetString("Tools.FileImport.ImportedFiles") + " " + rootPath + ": ";
        this.lblTargetAliasPath.Text = ResHelper.GetString("Tools.FileImport.TargetAliasPath");
        this.lblDeleteImported.Text = ResHelper.GetString("Tools.FileImport.DeleteImported");
        this.lblSelectCulture.Text = ResHelper.GetString("Tools.FileImport.Culture");
        this.btnStartImport.Text = ResHelper.GetString("Tools.FileImport.StartImport");


        //ltlChoosePath.Text = "<input class=\"formButton\" onclick=\"window.open('../../Content/SelectNodeFrameset.aspx?targetID=txtTargetAliasPath&pathtype=aliaspath', '_blank', 'height=500,width=600,left=100,top=50,location=no,menubar=no,resizable=yes,scrollbars=yes,status=no,titlebar=yes,toolbar=no');\" type=\"button\" value=\"" + ResMan.GetString("Tools.FileImport.SelectPath") + "\">";

        if (!(this.IsPostBack))
        {
            InitializeDrpSelectCulture();
            
        }
        LoadDataGrid();

        this.dtgFiles.Columns[0].HeaderText = ResHelper.GetString("Tools.FileImport.DataGrid.ColumnSelect");
        this.dtgFiles.Columns[1].HeaderText = ResHelper.GetString("Tools.FileImport.DataGrid.ColumnFile");
        this.dtgFiles.Columns[2].HeaderText = ResHelper.GetString("Tools.FileImport.DataGrid.ColumnResult");
    }

    private void InitializeDrpSelectCulture()
    {
        drpSelectCulture.DataSource = CultureInfoProvider.GetSiteCultures(CMSContext.CurrentSite.SiteName);
        drpSelectCulture.DataTextField = "CultureName";
        drpSelectCulture.DataValueField = "CultureCode";
        drpSelectCulture.DataBind();

        if (drpSelectCulture.Items[0].Text == "System.Data.DataRowView")
        {
            drpSelectCulture.Items[0].Text = CMSContext.CurrentUser.PreferredCultureCode;
            drpSelectCulture.Items[0].Value = CMSContext.CurrentUser.PreferredCultureCode;
        }
        try
        {
            drpSelectCulture.SelectedValue = CMSContext.CurrentUser.PreferredCultureCode;
        }
        catch
        {
        }     
    }


    private void LoadDataGrid()
    {
        dt.Columns.Clear();
        dt.Columns.Add("FileID");
        dt.Columns.Add("FileVirtualPath");
        dt.Columns.Add("Result");

        files.Items.Clear();

        getFilesInDir(rootPath, rootPath);

        dt.Rows.Clear();
        int count = 0;
        int resultIndex = 0;
        foreach (System.Web.UI.WebControls.ListItem file in files.Items)
        {
            DataRow row = dt.NewRow();
            row["FileID"] = count;
            row["FileVirtualPath"] = file.ToString();

            // if result could be load from resultList
            if (!(resultList == null) && resultIndex < resultList.Count && !(resultList[resultIndex] == null))
            {
                row["Result"] = System.Convert.ToString(resultList[resultIndex]) + "";
            }
            else
            {
                row["Result"] = "";
            }

            dt.Rows.Add(row);

            resultIndex += 1;
        }

        this.dtgFiles.DataSource = dt;
        this.dtgFiles.DataBind();
    }


    private void getFilesInDir(string path, string rootPath)
    {
        FileInfo file = null;
        DirectoryInfo directory = null;
        DirectoryInfo pathDir = new DirectoryInfo(path);
        string fileName = null;
        string filePath = null;

        if (!(Directory.Exists(path)))
        {
            return;
        }

        foreach (System.IO.DirectoryInfo dir in pathDir.GetDirectories())
        {
            directory = dir;
            if (DirectoryHelper.CheckPermissions(directory.FullName, true, false, false, false))
            {
                getFilesInDir(directory.FullName, rootPath);
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Tools.FileImport.NoReadPermissionForDirectory") + " " + directory.FullName + " .";                
            }
        }

        foreach (System.IO.FileInfo fl in pathDir.GetFiles())
        {
            file = fl; 
            fileName = file.Name;
            filePath = file.FullName.Substring(rootPath.Length+1).Replace(@"\", "/");
            files.Items.Add(filePath);
        }
    }

    protected void btnStartImport_Click(System.Object sender, System.EventArgs e)
    {
        string siteName = CMSContext.CurrentSite.SiteName;
        int userId = CMSContext.CurrentUser.UserID;
        string cultureCode = CMSContext.CurrentUser.PreferredCultureCode;
        string[] fileList = null;
        string[] relativePathList = null;
        ArrayList fileArray = new ArrayList();
        string targetAliasPath = "";

        targetAliasPath = txtTargetAliasPath_name.Text;

        //insert files selected in datagrid to list of files to import
        string errorMsg = "";
        for (int i = 0; i < dtgFiles.Rows.Count; i++)
        {
            CheckBox chk = ((CheckBox)(dtgFiles.Rows[i].Cells[0].FindControl("chkSelect" + i.ToString())));
            if ((chk != null) && (chk.Checked))
            {
                //fileArray.Add(rootPath + item.Cells[1].Text.Replace("/", "\\"));
                fileList = new string[1];
                fileList[0] = rootPath + "\\" + dtgFiles.Rows[i].Cells[1].Text.Replace("/", "\\");
                relativePathList = new string[1];
                relativePathList[0] = dtgFiles.Rows[i].Cells[1].Text.Replace("/", "\\");
                try
                {
                    FileImport.ImportFiles(siteName, targetAliasPath, cultureCode, fileList, relativePathList, userId, chkDeleteImported.Checked);
                    if (!chkDeleteImported.Checked)
                    {
                        resultList.Add(ResHelper.GetString("Tools.FileImport.Imported"));
                    }
                }
                catch (Exception ex)
                {
                    resultList.Add(ResHelper.GetString("Tools.FileImport.Failed"));
                    errorMsg = ex.Message;
                }
            }
            else
            {
                resultList.Add("");
            }
        }
        if (errorMsg == "")
        {
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("Tools.FileImport.FilesWereImported");
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("Tools.FileImport.FilesNotImported") + " (" + errorMsg + ")";
        }
        LoadDataGrid();
    }

    protected void dtgFiles_DataBound(object sender, EventArgs e)
    {
        for (int i = 0; i < dtgFiles.Rows.Count; i++)
        {
            CheckBox isSelected = new CheckBox();
            isSelected.ID = "chkSelect" + i.ToString();
            isSelected.Checked = true;
            dtgFiles.Rows[i].Cells[0].Controls.Add(isSelected);
        }
    }
}
