using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Newsletter;
using CMS.Scheduler;

public partial class CMSDesk_Tools_Newsletters_Newsletters_Newsletter_New : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        rfvNewsletterDisplayName.ErrorMessage = ResHelper.GetString("Newsletter_Edit.ErrorEmptyDisplayName");
        rfvNewsletterName.ErrorMessage = ResHelper.GetString("Newsletter_Edit.ErrorEmptyName");
        rfvNewsletterSenderName.ErrorMessage = ResHelper.GetString("Newsletter_Edit.ErrorEmptySenderName");
        rfvNewsletterSenderEmail.ErrorMessage = ResHelper.GetString("Newsletter_Edit.ErrorEmptySenderEmail");
        rfvIssueTemplate.ErrorMessage = ResHelper.GetString("Newsletter_Edit.NoEmailTemplateSelected");
        rfvSubscriptionTemplate.ErrorMessage = ResHelper.GetString("Newsletter_Edit.NoSubscriptionTemplateSelected");;
        rfvUnsubscriptionTemplate.ErrorMessage = ResHelper.GetString("Newsletter_Edit.NoUnsubscriptionTemplateSelected");

        lblNewsletterDynamicScheduledTaskID.Text = ResHelper.GetString("Newsletter_Edit.NewsletterDynamicScheduledTaskIDLabel");
        lblNewsletterName.Text = ResHelper.GetString("Newsletter_Edit.NewsletterNameLabel");
        lblNewsletterDisplayName.Text = ResHelper.GetString("Newsletter_Edit.NewsletterDisplayNameLabel");
        lblNewsletterSenderName.Text = ResHelper.GetString("Newsletter_Edit.NewsletterSenderNameLabel");
        lblNewsletterDynamicURL.Text = ResHelper.GetString("Newsletter_Edit.NewsletterDynamicURLLabel");
        lblNewsletterSenderEmail.Text = ResHelper.GetString("Newsletter_Edit.NewsletterSenderEmailLabel");
        lblSubscriptionTemplate.Text = ResHelper.GetString("Newsletter_Edit.SubscriptionTemplate");
        lblUnsubscriptionTemplate.Text = ResHelper.GetString("Newsletter_Edit.UnsubscriptionTemplate");
        lblIssueTemplate.Text = ResHelper.GetString("Newsletter_Edit.NewsletterTemplate");
        lblDynamic.Text = ResHelper.GetString("Newsletter_Edit.Dynamic");
        lblTemplateBased.Text = ResHelper.GetString("Newsletter_Edit.TemplateBased");
        lblNewsletterDynamicURL.Text = ResHelper.GetString("Newsletter_Edit.SourcePageURL");
        lblSchedule.Text = ResHelper.GetString("Newsletter_Edit.Schedule");
        btnOK.Text = ResHelper.GetString("General.OK");

        string currentNewsletter = ResHelper.GetString("Newsletter_Edit.NewItemCaption");

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("Newsletter_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Newsletters/Newsletters/Newsletter_List.aspx";
        pageTitleTabs[0, 2] = "newslettersContent";
        pageTitleTabs[1, 0] = currentNewsletter;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("Newsletter_Edit.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Newsletters/Newsletters/newnewsletter.gif";

        if (!IsPostBack)
        {
            int siteId = CMSContext.CurrentSite.SiteID;
            LoadDrpSubscription(siteId);
            LoadDrpUnsubscription(siteId);
            LoadDrpIssueTemplates(siteId);
            radDynamic.Checked = false;
            radTemplateBased.Checked = true;
            SetTypeToTemplateBased();
        }
    }

    protected void LoadDrpSubscription(int siteId)
    {
        drpSubscriptionTemplate.DataSource = EmailTemplateProvider.GetAllSubscriptionTemplates(siteId);
        drpSubscriptionTemplate.DataValueField = "TemplateID";
        drpSubscriptionTemplate.DataTextField = "TemplateDisplayName";
        drpSubscriptionTemplate.DataBind();
        if (drpSubscriptionTemplate.Items.Count > 0)
        {
            drpSubscriptionTemplate.SelectedIndex = 0;
        }
    }

    protected void LoadDrpUnsubscription(int siteId)
    {
        drpUnsubscriptionTemplate.DataSource = EmailTemplateProvider.GetAllUnsubscriptionTemplates(siteId);
        drpUnsubscriptionTemplate.DataValueField = "TemplateID";
        drpUnsubscriptionTemplate.DataTextField = "TemplateDisplayName";
        drpUnsubscriptionTemplate.DataBind();
        if (drpUnsubscriptionTemplate.Items.Count > 0)
        {
            drpUnsubscriptionTemplate.SelectedIndex = 0;
        }
    }

    protected void LoadDrpIssueTemplates(int siteId)
    {
        drpIssueTemplate.DataSource = EmailTemplateProvider.GetAllIssueTemplates(siteId);
        drpIssueTemplate.DataValueField = "TemplateID";
        drpIssueTemplate.DataTextField = "TemplateDisplayName";
        drpIssueTemplate.DataBind();
        if (drpIssueTemplate.Items.Count > 0)
        {
            drpIssueTemplate.SelectedIndex = 0;
        }
    }

    protected void SetTypeToTemplateBased()
    {
        drpIssueTemplate.Enabled = true;
        txtNewsletterDynamicURL.Enabled = false;
        lblSchedule.Visible = false;
        ScheduleInterval1.Visible = false;
    }

    protected void SetTypeToDynamic()
    {
        drpIssueTemplate.Enabled = false;
        txtNewsletterDynamicURL.Enabled = true;
        lblSchedule.Visible = true;
        ScheduleInterval1.Visible = true;
    }



    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.newsletter", "configure"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.newsletter", "configure");
        }
        string errorMessage = new Validator().NotEmpty(txtNewsletterDisplayName.Text, ResHelper.GetString("Newsletter_Edit.ErrorEmptyDisplayName")).NotEmpty(txtNewsletterName.Text, ResHelper.GetString("Newsletter_Edit.ErrorEmptyName")).NotEmpty(txtNewsletterSenderName.Text, ResHelper.GetString("Newsletter_Edit.ErrorEmptySenderName")).NotEmpty(txtNewsletterSenderEmail.Text, ResHelper.GetString("Newsletter_Edit.ErrorEmptySenderEmail")).Result;

        if (errorMessage == "")
        {
            if ((radDynamic.Checked)&&(ScheduleInterval1.ScheduleInterval == ";1/1/0001 12:00:00 AM"))
            {
                //if problem occured while setting schedule interval
                return;
            }
            // newsletterName must to be unique
            Newsletter newsletterObj = NewsletterProvider.GetNewsletter(txtNewsletterName.Text.Trim(), CMSContext.CurrentSite.SiteID);

            // if newsletterName value is unique														
            if (newsletterObj == null)
            {
                // create new item -> insert
                newsletterObj = new Newsletter();

                newsletterObj.NewsletterDisplayName = txtNewsletterDisplayName.Text.Trim();
                newsletterObj.NewsletterName = txtNewsletterName.Text.Trim();
                if (drpSubscriptionTemplate.SelectedIndex > -1)
                {
                    newsletterObj.NewsletterSubscriptionTemplateID = Convert.ToInt32(drpSubscriptionTemplate.SelectedValue);
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Newsletter_Edit.NoSubscriptionTemplateSelected");
                    return;
                }
                if (drpUnsubscriptionTemplate.SelectedIndex > -1)
                {
                    newsletterObj.NewsletterUnsubscriptionTemplateID = Convert.ToInt32(drpUnsubscriptionTemplate.SelectedValue);
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Newsletter_Edit.NoUnsubscriptionTemplateSelected");
                    return;
                }
                newsletterObj.NewsletterSenderName = txtNewsletterSenderName.Text.Trim();
                newsletterObj.NewsletterSenderEmail = txtNewsletterSenderEmail.Text.Trim();
                if (radDynamic.Checked)
                {
                    newsletterObj.NewsletterDynamicURL = txtNewsletterDynamicURL.Text.Trim();
                    newsletterObj.NewsletterType = "D";
                }
                else
                {
                    if (drpIssueTemplate.SelectedIndex > -1)
                    {
                        newsletterObj.NewsletterTemplateID = Convert.ToInt32(drpIssueTemplate.SelectedValue);
                    }
                    else
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("Newsletter_Edit.NoEmailTemplateSelected");
                        return;
                    }
                    newsletterObj.NewsletterType = "T";
                }
                newsletterObj.NewsletterSiteID = CMS.CMSHelper.CMSContext.CurrentSite.SiteID;
                newsletterObj.NewsletterGUID = Guid.NewGuid();

                //create new newsletter
                NewsletterProvider.SetNewsletter(newsletterObj);
                
                if (radDynamic.Checked)
                {
                    //Create new task to schedule the dynamic newsletter
                    TaskInfo task = new TaskInfo();
                    task.TaskAssemblyName = "CMS.Newsletter";
                    task.TaskClass = "CMS.Newsletter.DynamicNewsletterSender";
                    task.TaskDisplayName = "Send dynamic newsletter: " + newsletterObj.NewsletterName;
                    task.TaskEnabled = true;
                    task.TaskInterval = ScheduleInterval1.ScheduleInterval;
                    task.TaskLastResult = "";
                    task.TaskName = "DynamicNewsletter:" + newsletterObj.NewsletterName;
                    task.TaskSiteID = CMSContext.CurrentSite.SiteID;
                    task.TaskNextRunTime = SchedulingHelper.GetNextTime(task.TaskInterval, new DateTime());
                    task.TaskData = newsletterObj.NewsletterID.ToString();
                    
                    TaskInfoProvider.SetTaskInfo(task);
                    //DynamicNewsletterSender dns = new DynamicNewsletterSender();
                    //dns.Execute(task);
                    
                    newsletterObj.NewsletterDynamicScheduledTaskID = task.TaskID;
                    NewsletterProvider.SetNewsletter(newsletterObj);
                }
                Response.Redirect("Newsletter_Frameset.aspx?newsletterid=" + Convert.ToString(newsletterObj.NewsletterID) + "&saved=1");
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Newsletter_Edit.NewsletterNameExists");
            }

        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }


    protected void radTemplateBased_CheckedChanged(object sender, EventArgs e)
    {
        if (radDynamic.Checked)
        {
            SetTypeToDynamic();
        }
        else
        {
            SetTypeToTemplateBased();
        }
    }
    protected void radDynamic_CheckedChanged(object sender, EventArgs e)
    {
        if (radDynamic.Checked)
        {
            SetTypeToDynamic();
        }
        else
        {
            SetTypeToTemplateBased();
        }
    }
}
