using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.PortalEngine;

public partial class CMSSiteManager_Development_WebContainer_Container_Edit : SiteManagerPage
{
    protected int containerId = 0;

    bool isEdit = false;

    protected void Page_Load(object sender, EventArgs e)
    {
        rfvDisplayName.ErrorMessage = ResHelper.GetString("Container_Edit.rfvDisplayName");
        rfvCodeName.ErrorMessage = ResHelper.GetString("Container_Edit.rfvCodeName");


        // control initializations				
        lblContainerTextBefore.Text = ResHelper.GetString("Container_Edit.ContainerTextBeforeLabel");
        lblContainerTextAfter.Text = ResHelper.GetString("Container_Edit.ContainerTextAfterLabel");
        lblContainerName.Text = ResHelper.GetString("Container_Edit.ContainerNameLabel");
        lblContainerDisplayName.Text = ResHelper.GetString("Container_Edit.ContainerDisplayNameLabel");

        btnOK.Text = ResHelper.GetString("General.OK");

        string currentWebPartContainer = ResHelper.GetString("Container_Edit.NewItemCaption");


        // get webPartContainer id from querystring
        if ((Request.QueryString["containerid"] != null) && (Request.QueryString["containerid"] != ""))
        {
            containerId = Convert.ToInt32(Request.QueryString["containerid"]);
            WebPartContainerInfo webPartContainerObj = WebPartContainerInfoProvider.GetWebPartContainerInfo(containerId);
            currentWebPartContainer = webPartContainerObj.ContainerDisplayName;

            if (webPartContainerObj != null)
                isEdit = true;

            // fill editing form
            if (!IsPostBack)
            {
                LoadData(webPartContainerObj);

                // show that the webPartContainer was created or updated successfully
                if (Request.QueryString["saved"] == "1")
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
        }

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("Container_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSSiteManager/Development/WebContainers/Container_List.aspx";
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = currentWebPartContainer;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;

        if (isEdit)
        {
            PageTitle.TitleText = ResHelper.GetString("Container_Edit.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/WebContainers/container.gif";
        }
        else
        {
            PageTitle.TitleText = ResHelper.GetString("Container_Edit.NewHeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/WebContainers/newcontainer.gif";
        }
    }


    /// <summary>
    /// Load data of editing webPartContainer.
    /// </summary>
    /// <param name="webPartContainerObj">WebPartContainer object.</param>
    protected void LoadData(WebPartContainerInfo webPartContainerObj)
    {

        txtContainerTextBefore.Text = webPartContainerObj.ContainerTextBefore;
        txtContainerTextAfter.Text = webPartContainerObj.ContainerTextAfter;
        txtContainerName.Text = webPartContainerObj.ContainerName;
        txtContainerDisplayName.Text = webPartContainerObj.ContainerDisplayName;

    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        string errorMessage = new Validator().NotEmpty(txtContainerDisplayName, rfvDisplayName.ErrorMessage).NotEmpty(txtContainerName, rfvCodeName.ErrorMessage).Result;

        if (errorMessage == "")
        {
            WebPartContainerInfo webPartContainerObj = WebPartContainerInfoProvider.GetWebPartContainerInfo(containerId);

            // if webPartContainer doesnt already exist, create new one
            if (webPartContainerObj == null)
            {
                webPartContainerObj = new WebPartContainerInfo();
            }
            webPartContainerObj.ContainerTextBefore = txtContainerTextBefore.Text;
            webPartContainerObj.ContainerTextAfter = txtContainerTextAfter.Text;
            webPartContainerObj.ContainerName = txtContainerName.Text.Trim();
            webPartContainerObj.ContainerDisplayName = txtContainerDisplayName.Text.Trim();

            WebPartContainerInfo wPcI = WebPartContainerInfoProvider.GetWebPartContainerInfo(webPartContainerObj.ContainerName);

            if ((wPcI != null) && (wPcI.ContainerID != containerId))
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Container_Edit.UniqueError");
                return;
            }

            WebPartContainerInfoProvider.SetWebPartContainerInfo(webPartContainerObj);

            Response.Redirect("Container_Edit.aspx?containerid=" + Convert.ToString(webPartContainerObj.ContainerID) + "&saved=1");
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
