using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.ImportExport;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.SettingsProvider;


public partial class Import_ObjectsWizard : System.Web.UI.UserControl
{
    #region Properties
    /// <summary>
    /// Import settings stored in viewstate
    /// </summary>
    public SiteImportSettings ImportSettings
    {
        get
        {
            if (ViewState["settings"] == null)
            {
                throw new Exception("[Import_ObjectsWizard]: ImportSettings not initialized!");
            }
            return (SiteImportSettings)ViewState["settings"];
        }
        set
        {
            ViewState["settings"] = value;
        }
    }


    /// <summary>
    /// Real index
    /// </summary>
    private int WizardIndex
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["globalIndex"], 1);
        }
        set
        {
            ViewState["globalIndex"] = value;
        }
    }


    /// <summary>
    /// Flag if this is only settings import
    /// </summary>
    public bool ImportOnlySettings
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["importOnlySettings"], false);
        }
        set
        {
            ViewState["importOnlySettings"] = value;
        }
    }


    /// <summary>
    /// Start index
    /// </summary>
    public int StartIndex
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["startIndex"], -1);
        }
        set
        {
            ViewState["startIndex"] = value;
        }
    }


    /// <summary>
    /// Caption index
    /// </summary>
    public int CaptionIndex
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["captionIndex"], -1);
        }
        set
        {
            ViewState["captionIndex"] = value;
            // First step caption
            lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.StepImportType.lblStepImportType"), CaptionIndex + "." + WizardIndex);
        }
    }


    /// <summary>
    /// Result
    /// </summary>
    public ResultEnum Result
    {
        get
        {
            if (ViewState["result"] == null)
            {
                ViewState["result"] = ResultEnum.Success;
            }
            return (ResultEnum)ViewState["result"];
        }
        set
        {
            ViewState["result"] = value;
        }
    }


    /// <summary>
    /// Result warning messages
    /// </summary>
    public ArrayList WarningMessages
    {
        get
        {
            if (ViewState["resultWarningMessage"] == null)
            {
                ViewState["resultWarningMessage"] = new ArrayList();
            }
            return (ArrayList)ViewState["resultWarningMessage"];
        }
        set
        {
            ViewState["resultWarningMessage"] = value;
        }
    }


    /// <summary>
    /// Permission messages
    /// </summary>
    public ArrayList PermissionMessages
    {
        get
        {
            if (ViewState["permissionMessage"] == null)
            {
                ViewState["permissionMessage"] = new ArrayList();
            }
            return (ArrayList)ViewState["permissionMessage"];
        }
        set
        {
            ViewState["permissionMessage"] = value;
        }
    }


    /// <summary>
    /// Imported css styles
    /// </summary>
    private ArrayList ImportedStyles
    {
        get
        {
            if (ViewState["cssStyles"] == null)
            {
                ViewState["cssStyles"] = new ArrayList();
            }
            return (ArrayList)ViewState["cssStyles"];
        }
    }


    /// <summary>
    /// Flag if documents are imported
    /// </summary>
    private bool DocumentsImported
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["docImported"], false);
        }
        set
        {
            ViewState["docImported"] = value;
        }
    }


    /// <summary>
    /// Wizard in which is this user control included
    /// </summary>

    private Wizard mWizard = null;

    public Wizard Wizard
    {
        get
        {
            if (mWizard == null)
            {
                throw new Exception("[Import_ObjectsWizard]: Wizard propety not initialised!");
            }
            return mWizard;
        }
        set
        {
            mWizard = (Wizard)value;
        }
    }


    /// <summary>
    /// True if last step finishes the wizard
    /// </summary>
    public bool LastStepFinish
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["lastStepFinish"], false);
        }
        set
        {
            ViewState["lastStepFinish"] = value;
        }
    }

    #endregion

    #region Events
    ///<summary>Occurs after the wizard is finished.</summary>
    public delegate void OnFinishHandler();
    ///<summary>OnFinish event.</summary>
    public event OnFinishHandler OnFinish;
    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            wzdImport.StartNextButtonText = ResHelper.GetString("ImportSite.NextStep");
            wzdImport.StepNextButtonText = ResHelper.GetString("ImportSite.NextStep");

            lblStepDesc.Text = ResHelper.GetString("ImportSite.Step.wizardIntro");


            wzdImport.ActiveStepIndex = 0;

            // First step caption
            lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.StepImportType.lblStepImportType"), CaptionIndex + "." + WizardIndex);
        }
    }

    protected void wzdImport_NextButtonClick(object sender, WizardNavigationEventArgs e)
    {
        ++WizardIndex;
        lblError.Visible = false;

        // handles wizards steps
        switch (e.CurrentStepIndex)
        {
            case 0:
                ImportSettings.ImportOnlySettings = ImportOnlySettings;
                if (!ucImportType.SelectObjects)
                {
                    wzdImport.ActiveStepIndex = wzdImport.WizardSteps.Count - 1;

                    // tries import site
                    try
                    {
                        // Do not resolve conflicts manually, act like web template
                        ImportSettings.OverwriteAll = true;

                        // Import site
                        ImportProvider.ImportSite(ImportSettings);

                        // Hide current wizard and show the old
                        HideWizard();

                        if (!ImportOnlySettings && (ImportSettings.PermissionWarningMessages.Count == 0))
                        {
                            // Run site
                            SiteInfoProvider.RunSite(ImportSettings.NewSiteName);
                        }

                        DeleteTempFiles();
                        if (OnFinish != null)
                        {
                            if (ImportSettings.PermissionWarningMessages.Count != 0)
                            {
                                Result = ResultEnum.Warning;
                                PermissionMessages = ImportSettings.PermissionWarningMessages;
                            }
                            OnFinish();
                        }
                    }
                    catch (RunningSiteException ex)
                    {
                        HandleWarning(ex);

                        DeleteTempFiles();
                        if (OnFinish != null)
                        {
                            PermissionMessages = ImportSettings.PermissionWarningMessages;
                            OnFinish();
                        }
                    }
                    catch (Exception ex)
                    {
                        HandleError(ex, e);
                    }
                }
                else
                {
                    LoadData(e.CurrentStepIndex + 1);
                }
                break;
            // Set css styles and create site skeleton
            case 1:
                // Fill selected objects for the import provider
                ImportSettings.SelectedCssStyles = ucCssStyles.GetSelectedObjects();

                // Try import css styles, create site skeleton
                try
                {
                    ImportProvider.SetCssStyleSheets(ImportSettings, ImportedStyles);
                    if (!ImportOnlySettings)
                    {
                        ImportProvider.CreateSiteSkeleton(ImportSettings);
                        LoadData(e.CurrentStepIndex + 1);
                    }
                    else
                    {
                        wzdImport.ActiveStepIndex += 2;
                        LoadData(e.CurrentStepIndex + 2);
                    }
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set workflow
            case 2:
                // Fill selected objects for the import provider
                ImportSettings.SelectedWorkflows = ucWorkflows.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetWorkflows(ImportSettings);
                    LoadData(e.CurrentStepIndex + 1);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set page templates
            case 3:
                // Fill selected objects for the import provider
                ImportSettings.SelectedPageTemplates = ucPageTemplates.GetSelectedObjects();
                ImportSettings.SelectedLayouts = ucLayouts.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetPageTemplates(ImportSettings);
                    LoadData(e.CurrentStepIndex + 1);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set document types
            case 4:
                // Fill selected objects for the import provider
                ImportSettings.SelectedDocumentTypes = ucDocTypes.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetDocumentTypes(ImportSettings, null);
                    if (!ImportOnlySettings)
                    {
                        ImportProvider.CreateSiteRoot(ImportSettings);
                        ImportProvider.AddCssStyleSheetsToSite(ImportedStyles);
                        ImportProvider.SetDomainAliases(ImportSettings);
                        LoadData(e.CurrentStepIndex + 1);
                    }
                    else
                    {
                        wzdImport.ActiveStepIndex += 2;
                        LoadData(e.CurrentStepIndex + 2);
                    }
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set roles
            case 5:
                // Fill selected objects for the import provider
                ImportSettings.SelectedRoles = ucRoles.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetRoles(ImportSettings);
                    LoadData(e.CurrentStepIndex + 1);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set users
            case 6:
                // Fill selected objects for the import provider
                ImportSettings.SelectedUsers = ucUsers.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetUsersAndRoleRelations(ImportSettings);
                    if (!ImportOnlySettings)
                    {
                        ImportProvider.SetCultures(ImportSettings);
                        LoadData(e.CurrentStepIndex + 1);
                    }
                    else
                    {
                        wzdImport.ActiveStepIndex += 4;
                        LoadData(e.CurrentStepIndex + 4);
                    }
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set email templates
            case 7:
                // Fill selected objects for the import provider
                ImportSettings.SelectedLocalEmailTemplates = ucLocalEmailTemplates.GetSelectedObjects();
                ImportSettings.SelectedGlobalEmailTemplates = ucGlobalEmailTemplates.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetEmailTemplates(ImportSettings);
                    LoadData(e.CurrentStepIndex + 1);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set site settings, resources, permissions
            case 8:
                // Fill selected objects for the import provider
                ImportSettings.SelectedSiteSettings = ucSettings.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetSettingsAndCategories(ImportSettings);
                    ImportProvider.SetResources(ImportSettings);
                    ImportProvider.SetPermissions(ImportSettings);
                    LoadData(e.CurrentStepIndex + 1);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // If the documents should be imported, import it
            case 9:
                if (ucDocuments.ImportDocuments)
                {
                    try
                    {
                        ImportProvider.SetDocuments(ImportSettings);
                        DocumentsImported = true;
                        LoadData(e.CurrentStepIndex + 1);
                    }
                    catch (Exception ex)
                    {
                        HandleError(ex, e);
                    }
                }
                else
                {
                    LoadData(e.CurrentStepIndex + 1);
                }
                break;
            // Set webparts
            case 10:
                // Fill selected objects for the import provider
                ImportSettings.SelectedWebParts = ucWebParts.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetWebParts(ImportSettings);
                    LoadData(e.CurrentStepIndex + 1);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set webpart containers
            case 11:
                // Fill selected objects for the import provider
                ImportSettings.SelectedWebPartContainers = ucWebPartContainers.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetWebPartContainers(ImportSettings);
                    LoadData(e.CurrentStepIndex + 1);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set form user controls
            case 12:
                // Fill selected objects for the import provider
                ImportSettings.SelectedFormUserControls = ucFormUserCtrls.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetFormUserControls(ImportSettings);
                    if (!ImportOnlySettings)
                    {
                        ImportProvider.SetTranslationResourcesAndUICultures(ImportSettings);
                        if (DocumentsImported)
                        {
                            ImportProvider.SetAttachments(ImportSettings);
                            ImportProvider.SetScheduledTasks(ImportSettings);
                        }
                    }
                    LoadData(e.CurrentStepIndex + 1);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set inline controls
            case 13:
                // Fill selected objects for the import provider
                ImportSettings.SelectedInlineControls = ucInlineCtrls.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetInlineControls(ImportSettings);
                    if (!ImportOnlySettings)
                    {
                        LoadData(e.CurrentStepIndex + 1);
                    }
                    else
                    {
                        // Hide current wizard and show the old
                        HideWizard();

                        if (OnFinish != null)
                        {
                            if (ImportSettings.PermissionWarningMessages.Count != 0)
                            {
                                Result = ResultEnum.Warning;
                                PermissionMessages = ImportSettings.PermissionWarningMessages;
                            }
                            OnFinish();
                        }

                        DeleteTempFiles();
                    }
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            // Set relationship names
            case 14:
                // Fill selected objects for the import provider
                ImportSettings.SelectedRelationshipNames = ucRelationships.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.CopyAppCodeDir(ImportSettings);
                    ImportProvider.SetRelationshipNames(ImportSettings);
                    ImportProvider.SetBizForms(ImportSettings);
                    ImportProvider.SetNewsletters(ImportSettings);


                    // Hide current wizard and show the old
                    HideWizard();

                    if (ImportSettings.PermissionWarningMessages.Count == 0)
                    {
                        // Run site
                        SiteInfoProvider.RunSite(ImportSettings.NewSiteName);
                    }
                    DeleteTempFiles();

                    if (OnFinish != null)
                    {
                        PermissionMessages = ImportSettings.PermissionWarningMessages;
                        OnFinish();
                    }
                }
                catch (RunningSiteException ex)
                {
                    HandleWarning(ex);

                    DeleteTempFiles();

                    if (OnFinish != null)
                    {
                        PermissionMessages = ImportSettings.PermissionWarningMessages;
                        OnFinish();
                    }
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex, e);
                }
                break;
            default:
                break;
        }

    }


    private void LoadData(int stepIndex)
    {
        lblStepDesc.Visible = false;
        lblStepDesc.Text = ResHelper.GetString("ImportSite.Step.lblAsteriskExplanation");

        switch (stepIndex)
        {
            // Load data for stylesheets selection step
            case 1:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepCssStyles.lblStepCssStyles"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                ucCssStyles.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCssStyles.lblCssStyles");
                ucCssStyles.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCssStyles.noCssStyles");
                ucCssStyles.FirstBoundField = "StylesheetDisplayName";
                ucCssStyles.SecondBoundField = "StylesheetName";
                ucCssStyles.CheckBoxClass = "css";
                ucCssStyles.DataSet = ImportProvider.GetCssStyleSheetsDataSet(ImportSettings);
                ucCssStyles.Bind();
                break;
            // Load data for workflows
            case 2:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepWorkflows.lblStepWorkflows"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind workflows
                ucWorkflows.LabelCaption = ResHelper.GetString("SiteImport.wzdStepWorkflows.lblWorkflows");
                ucWorkflows.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepWorkflows.noWorkflows");
                ucWorkflows.FirstBoundField = "WorkflowDisplayName";
                ucWorkflows.SecondBoundField = "WorkflowName";
                ucWorkflows.CheckBoxClass = "workf";
                ucWorkflows.DataSet = ImportProvider.GetWorkflowsDataSet(ImportSettings);
                ucWorkflows.Bind();
                break;
            // Load data for page templates
            case 3:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepPageTemplates.lblStepPageTemplates"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind page templates
                ucPageTemplates.LabelCaption = ResHelper.GetString("SiteImport.wzdStepPageTemplates.lblPageTemplates");
                ucPageTemplates.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepPageTemplates.noPageTemplates");
                ucPageTemplates.FirstBoundField = "PageTemplateDisplayName";
                ucPageTemplates.SecondBoundField = "PageTemplateCodeName";
                ucPageTemplates.CheckBoxClass = "pt";
                ucPageTemplates.DataSet = ImportProvider.GetPageTemplatesDataSet(ImportSettings);
                ucPageTemplates.Bind();

                // Data bind layouts
                ucLayouts.LabelCaption = ResHelper.GetString("SiteImport.wzdStepPageTemplates.lblLayouts");
                ucLayouts.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepPageTemplates.noLayouts");
                ucLayouts.FirstBoundField = "LayoutDisplayName";
                ucLayouts.SecondBoundField = "LayoutCodeName";
                ucLayouts.CheckBoxClass = "lay";
                ucLayouts.DataSet = ImportProvider.GetLayoutsDataSet(ImportSettings);
                ucLayouts.Bind();
                break;
            // Load data for document types
            case 4:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepDocumentTypes.lblStepDocumentTypes"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind document types
                ucDocTypes.LabelCaption = ResHelper.GetString("SiteImport.wzdStepDocumentTypes.lblDocumentTypes");
                ucDocTypes.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepDocumentTypes.noDocumentTypes");
                ucDocTypes.FirstBoundField = "ClassDisplayName";
                ucDocTypes.SecondBoundField = "ClassName";
                ucDocTypes.CheckBoxClass = "doct";
                ucDocTypes.DataSet = ImportProvider.GetDocumentTypesDataSet(ImportSettings);
                ucDocTypes.Bind();
                break;
            // Load data for roles
            case 5:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepRoles.lblStepRoles"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind roles
                ucRoles.LabelCaption = ResHelper.GetString("SiteImport.wzdStepRoles.lblRoles");
                ucRoles.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepRoles.noRoles");
                ucRoles.FirstBoundField = "RoleDisplayName";
                ucRoles.SecondBoundField = "RoleName";
                ucRoles.CheckBoxClass = "rol";
                ucRoles.DataSet = ImportProvider.GetRolesDataSet(ImportSettings);
                ucRoles.Bind();
                break;
            // Load data for users
            case 6:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepUsers.lblStepUsers"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind users
                ucUsers.LabelCaption = ResHelper.GetString("SiteImport.wzdStepUsers.lblUsers");
                ucUsers.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepUsers.noUsers");
                ucUsers.FirstBoundField = "FullName";
                ucUsers.SecondBoundField = "UserName";
                ucUsers.CheckBoxClass = "usr";
                ucUsers.DataSet = ImportProvider.GetUsersDataSet(ImportSettings);
                ucUsers.Bind();
                break;
            // Load data for email templates
            case 7:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepEmailTemplates.lblStepEmailTemplates"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind local email templates
                ucLocalEmailTemplates.LabelCaption = ResHelper.GetString("SiteImport.wzdStepEmailTemplates.lblLocalEmailTemplates");
                ucLocalEmailTemplates.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepEmailTemplates.noLocalEmailTemplates");
                ucLocalEmailTemplates.FirstBoundField = "EmailTemplateDisplayName";
                ucLocalEmailTemplates.SecondBoundField = "EmailTemplateName";
                ucLocalEmailTemplates.CheckBoxClass = "leml";
                ucLocalEmailTemplates.DataSet = ImportProvider.GetLocalEmailTemplatesDataSet(ImportSettings);
                ucLocalEmailTemplates.Bind();

                // Data bind global email templates
                ucGlobalEmailTemplates.LabelCaption = ResHelper.GetString("SiteImport.wzdStepEmailTemplates.lblGlobalEmailTemplates");
                ucGlobalEmailTemplates.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepEmailTemplates.noGlobalEmailTemplates");
                ucGlobalEmailTemplates.FirstBoundField = "EmailTemplateDisplayName";
                ucGlobalEmailTemplates.SecondBoundField = "EmailTemplateName";
                ucGlobalEmailTemplates.CheckBoxClass = "geml";
                ucGlobalEmailTemplates.DataSet = ImportProvider.GetGlobalEmailTemplatesDataSet(ImportSettings);
                ucGlobalEmailTemplates.Bind();
                break;
            // Load data for settings
            case 8:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepSettings.lblStepSettings"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind settings
                ucSettings.LabelCaption = ResHelper.GetString("SiteImport.wzdStepSettings.lblSettings");
                ucSettings.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepSettings.noSettings");
                ucSettings.FirstBoundField = "KeyDisplayName";
                ucSettings.SecondBoundField = "KeyName";
                ucSettings.CheckBoxClass = "sett";
                ucSettings.DataSet = ImportProvider.GetSiteSettingsDataSet(ImportSettings);
                ucSettings.Bind();
                break;
            // Load data for documents
            case 9:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepDocuments.lblStepDocuments"), CaptionIndex + "." + WizardIndex);
                break;
            // Load data for webparts
            case 10:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepWebparts.lblStepWebparts"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web parts
                ucWebParts.LabelCaption = ResHelper.GetString("SiteImport.wzdStepWebparts.lblWebparts");
                ucWebParts.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepWebparts.noWebparts");
                ucWebParts.FirstBoundField = "WebPartDisplayName";
                ucWebParts.SecondBoundField = "WebPartName";
                ucWebParts.CheckBoxClass = "webp";
                ucWebParts.DataSet = ImportProvider.GetWebpartsDataSet(ImportSettings);
                ucWebParts.Bind();
                break;
            // Load data for webpart containers
            case 11:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepWebparts.lblStepWebpartContainers"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web parts
                ucWebPartContainers.LabelCaption = ResHelper.GetString("SiteImport.wzdStepWebparts.lblWebpartContainers");
                ucWebPartContainers.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepWebparts.noWebpartContainers");
                ucWebPartContainers.FirstBoundField = "ContainerDisplayName";
                ucWebPartContainers.SecondBoundField = "ContainerName";
                ucWebPartContainers.CheckBoxClass = "webc";
                ucWebPartContainers.DataSet = ImportProvider.GetWebpartContainersDataSet(ImportSettings);
                ucWebPartContainers.Bind();
                break;
            // Load data for form user controls
            case 12:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepFormUserControls.lblStepFormUserControls"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web parts
                ucFormUserCtrls.LabelCaption = ResHelper.GetString("SiteImport.wzdStepFormUserControls.lblFormUserControls");
                ucFormUserCtrls.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepFormUserControls.noFormUserControls");
                ucFormUserCtrls.FirstBoundField = "UserControlDisplayName";
                ucFormUserCtrls.SecondBoundField = "UserControlCodeName";
                ucFormUserCtrls.CheckBoxClass = "fuc";
                ucFormUserCtrls.DataSet = ImportProvider.GetFormUserControlsDataSet(ImportSettings);
                ucFormUserCtrls.Bind();
                break;
            // Load data for inline controls
            case 13:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepInlineControls.lblStepInlineControls"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web parts
                ucInlineCtrls.LabelCaption = ResHelper.GetString("SiteImport.wzdStepInlineControls.lblInlineControls");
                ucInlineCtrls.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepInlineControls.noInlineControls");
                ucInlineCtrls.FirstBoundField = "ControlDisplayName";
                ucInlineCtrls.SecondBoundField = "ControlName";
                ucInlineCtrls.CheckBoxClass = "inc";
                ucInlineCtrls.DataSet = ImportProvider.GetInlineControlsDataSet(ImportSettings);
                ucInlineCtrls.Bind();
                break;
            // Load data for reltionship names
            case 14:
                if (LastStepFinish)
                {
                    wzdImport.StepNextButtonText = ResHelper.GetString("ImportSite.Finish");
                }
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepRelationshipNames.lblStepRelationshipNames"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web parts
                ucRelationships.LabelCaption = ResHelper.GetString("SiteImport.wzdStepRelationshipNames.lblRelationshipNames");
                ucRelationships.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepRelationshipNames.noRelationshipNames");
                ucRelationships.FirstBoundField = "RelationshipDisplayName";
                ucRelationships.SecondBoundField = "RelationshipName";
                ucRelationships.CheckBoxClass = "relation";
                ucRelationships.DataSet = ImportProvider.GetRelationshipNamesDataSet(ImportSettings);
                ucRelationships.Bind();
                break;
            default:
                break;
        }
    }


    private void HandleError(Exception ex, WizardNavigationEventArgs e)
    {
        --WizardIndex;
        lblError.Visible = true;
        lblError.Text = string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
        //lblError.ToolTip = ex.StackTrace;
        e.Cancel = true;
    }


    private void HandleWarning(Exception ex)
    {
        Result = ResultEnum.Warning;
        WarningMessages.Add(ex.Message);
        //lblError.Visible = true;
        //lblError.Text = ex.Message; //string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
        //lblError.ToolTip = ex.StackTrace;
    }


    private void SetUserCulture(string siteName)
    {
        // Set current user default culture of the site
        CMSContext.CurrentUser.PreferredCultureCode = SettingsKeyProvider.GetStringValue(siteName + ".CMSDefaultCultureCode");
    }


    /// <summary>
    /// Handle next button click in the wizard
    /// </summary>
    /// <param name="wizard">Wizard</param>
    /// <param name="e">Wizard event argument</param>
    /// <param name="settings">Import settings</param>
    public int HandleNextButtonClick(WizardNavigationEventArgs e, SiteImportSettings settings, int wizardIndex)
    {
        if ((!e.Cancel) && (e.NextStepIndex == (StartIndex - 1)))
        {
            // Hide current wizard and display objectswizard
            //page.
            ShowWizard();
            ImportSettings = settings;
            return ++wizardIndex;
        }
        return wizardIndex;
    }


    private void HideWizard()
    {
        this.Parent.Visible = false;
        Wizard.Parent.Visible = true;
    }

    private void ShowWizard()
    {
        this.Parent.Visible = true;
        Wizard.Parent.Visible = false;
    }

    private void DeleteTempFiles()
    {
            try
            {
                ImportProvider.DeleteTemporaryFiles(ImportSettings, false);
            }
            catch (TemporaryFilesDeletionException ex)
            {
                HandleWarning(ex);
            }
    }
}
