using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.LicenseProvider;


public partial class SiteManager_Sites_Site_Edit_Cultures : SiteManagerPage
{
    protected int siteID = 0;
    protected string mSave = null;
    string imagesUrl = null;

    //data set of all cultures with JOINED column SiteID from CMS_SiteCulture table            
    protected DataSet ds = null; 

    protected void Page_Load(object sender, EventArgs e)
    {
        imagesUrl = ResolveUrl("~/App_Themes/" + this.Page.Theme + "/Images/General/");

        this.imgSave.ImageUrl = imagesUrl + "save.gif";
        mSave = ResHelper.GetString("EditMenu.IconSave");

        if ((Request.QueryString["siteID"] != null) && (Request.QueryString["siteID"] != ""))
        {
            siteID = Convert.ToInt32(Request.QueryString["siteID"]);

            if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
            {
                LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Multilingual);
            }
           
            lblCultureTitle.Text = ResHelper.GetString("Site_Edit_Cultures.CultureTitle");
            //btnOK.Text = ResHelper.GetString("Site_Edit_Cultures.OK");
            gvCultureList.Columns[0].HeaderText = ResHelper.GetString("Site_Edit_Cultures.Select");
            gvCultureList.Columns[1].HeaderText = ResHelper.GetString("Site_Edit_Cultures.CultureName");

            //data set of all cultures with JOINED column SiteID from CMS_SiteCulture table 
            ds = GetCulturesPerSite(siteID);
            gvCultureList.DataSource = ds.Tables[0];

            // make column with CultureID visible to set CultureID correctly
            gvCultureList.Columns[2].Visible = true;

            gvCultureList.DataBind();

            // hide column with siteID
            gvCultureList.Columns[2].Visible = false;

            gvCultureList.GridLines = GridLines.Horizontal;
        }
    }

    protected void gvSites_DataBound(object sender, EventArgs e)
    {       
        for (int i = 0; i < ds.Tables[0].Rows.Count; i++)
        {

            CheckBox hasThisCulture = new CheckBox();
            hasThisCulture.Checked = (ds.Tables[0].Rows[i]["SiteID"] == DBNull.Value) ? false : true;
            gvCultureList.Rows[i].Cells[0].Controls.Add(hasThisCulture);

        }

        // hide column with siteID
        gvCultureList.Columns[2].Visible = false;
    }


    protected void btnOK_Click(object sender, EventArgs e)
    {

       // int cultureIDFromCMSCulture;
        string cultureCode = "";
        int siteIDFromCMSSiteCulture;

        // make column with siteID visible to get siteID
        gvCultureList.Columns[2].Visible = true;        

        for (int i = 0; i < ds.Tables[0].Rows.Count; i++)
        {

            // get siteID from CMS_SiteCulture table
            if (ds.Tables[0].Rows[i]["SiteID"] == DBNull.Value)
            {
                siteIDFromCMSSiteCulture = 0;
            }
            else
            {
                siteIDFromCMSSiteCulture = Convert.ToInt32(ds.Tables[0].Rows[i]["SiteID"]);
            }

            // get culture code of the current culture
            cultureCode = Convert.ToString(ds.Tables[0].Rows[i]["CultureCode"]);

            // site has not specified current culture
            if (siteIDFromCMSSiteCulture == 0)
            {
                // if checkebox is checked, add culture to the site
                if (((CheckBox)gvCultureList.Rows[i].Cells[0].Controls[0]).Checked)
                {
                    CultureInfoProvider.AddCultureToSite(cultureCode, SiteInfoProvider.GetSiteInfo(siteID).SiteName);
                }
            }

            // site has specified current culture
            else
            {
                // if checkebox is not checked, remove culture from the site
                if (!((CheckBox)gvCultureList.Rows[i].Cells[0].Controls[0]).Checked)
                {
                    CultureInfoProvider.RemoveCultureFromSite(cultureCode, SiteInfoProvider.GetSiteInfo(siteID).SiteName);
                }

            }
        }

        // hide column with siteID
        gvCultureList.Columns[2].Visible = false;

        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
    }


    /// <summary>
    /// Returns dataset of all cultures with joined column SiteID from CMS_SiteCulture table
    /// </summary>
    /// <param name="siteID">ID of the editing site</param>
    /// <returns></returns>
    protected static DataSet GetCulturesPerSite(int siteID)
    {
        GeneralConnection genConn = new GeneralConnection();

        object[,] parameters = new object[1, 3];
        parameters[0, 0] = "@siteID";
        parameters[0, 1] = siteID;

        DataSet ds = genConn.ExecuteQuery("cms.site.selectcultures", parameters, null, "CMS_Culture.CultureName");
        return ds;
    }
}
