using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.CMSHelper;

public partial class SiteManager_Sites_Site_Edit_General : SiteManagerPage
{
    protected int siteId = 0;
    protected string siteName = "";

    protected void Page_Load(object sender, EventArgs e)
    {
        RequiredFieldValidatorCodeName.ErrorMessage = ResHelper.GetString("Administration-Site_Edit.RequiresCodeName");
        RequiredFieldValidatorDisplayName.ErrorMessage = ResHelper.GetString("Administration-Site_Edit.RequiresDisplayName");
        RequiredFieldValidatorDomainName.ErrorMessage = ResHelper.GetString("Administration-Site_Edit.RequiresDomainName");

        lblCodeName.Text = ResHelper.GetString("Site_Edit.CodeName");
        lblDescription.Text = ResHelper.GetString("Site_Edit.Description");
        lblDisplayName.Text = ResHelper.GetString("Site_Edit.DisplayName");
        lblDomainName.Text = ResHelper.GetString("Site_Edit.DomainName");
        lblCulture.Text = ResHelper.GetString("Site_Edit.ContentCulture");
        //lblLicenseKey.Text = ResHelper.GetString("Site_Edit.LicenseKey");
        lblCssStyle.Text = ResHelper.GetString("NewSite_SiteDetails.CssStyle");
        lblEditorStyle.Text = ResHelper.GetString("Site_Edit.EditorStyleSheet");
        lblVisitorCulture.Text = ResHelper.GetString("Site_Edit.VisitorCulture");
        ButtonOk.Text = ResHelper.GetString("Site_Edit.OK");

        siteId = ValidationHelper.GetInteger(Request.QueryString["siteid"], 0);

        if ((siteId > 0) && (!IsPostBack))
        {
            SiteInfo currentSiteInfo = SiteInfoProvider.GetSiteInfo(siteId);
            if ((currentSiteInfo != null) && (currentSiteInfo.SiteName != null))
            {
                siteName = currentSiteInfo.SiteName;

                // fill dropdown lists with ccs style sheets
                FillCssStylesheetDrops(siteName);

                TextBoxCodeName.Text = siteName;
                TextBoxDescription.Text = currentSiteInfo.Description;
                TextBoxDisplayName.Text = currentSiteInfo.DisplayName;
                TextBoxDomainName.Text = currentSiteInfo.DomainName;
                //TextBoxLicenseKey.Text = currentSiteInfo.LicenseKey;
                drpCssStyle.SelectedValue = Convert.ToString(currentSiteInfo.SiteDefaultStylesheetID);
                drpEditorStyle.SelectedValue = Convert.ToString(currentSiteInfo.SiteDefaultEditorStylesheet);
                if (CultureHelper.GetDefaultCulture(siteName) != null)
                {
                    CultureInfo ci = CultureInfoProvider.GetCultureInfo(CultureHelper.GetDefaultCulture(siteName));

                    if (ci != null)
                    {
                        lblCultureValue.Text = ci.CultureName;
                    }
                }

                // Load visitor content culture
                LoadCultureData(siteName);

                // Set actual content culture
                if ((currentSiteInfo.DefaultVisitorCulture != null) && (currentSiteInfo.DefaultVisitorCulture != ""))
                {

                    for (int i = 0; i < drpVisitorCulture.Items.Count; i++)
                    {
                        if (drpVisitorCulture.Items[i].Value == currentSiteInfo.DefaultVisitorCulture)
                        {
                            drpVisitorCulture.Items[i].Selected = true;
                        }
                    }
                }

            }
        }

    }


    protected void LoadCultureData(string siteName)
    {

        DataSet mDs = new DataSet();
        mDs = CultureInfoProvider.GetSiteCultures(siteName);

        if (mDs != null)
        {
            drpVisitorCulture.DataSource = mDs;
            drpVisitorCulture.DataTextField = mDs.Tables[0].Columns["CultureName"].ColumnName.ToString();
            drpVisitorCulture.DataValueField = mDs.Tables[0].Columns["CultureCode"].ColumnName.ToString();

            drpVisitorCulture.DataBind();
        }

        drpVisitorCulture.Items.Insert(0, ResHelper.GetString("Site_Edit.Automatic"));
        drpVisitorCulture.Items[0].Value = "";
    }


    /// <summary>
    /// Save current site's data.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ButtonOk_Click(object sender, EventArgs e)
    {
        // Finds whether required fields are not empty
        string result = new Validator().NotEmpty(TextBoxDisplayName.Text, ResHelper.GetString("Administration-Site_Edit.RequiresDisplayName")).NotEmpty(TextBoxCodeName.Text, ResHelper.GetString("Administration-Site_Edit.RequiresCodeName")).NotEmpty(TextBoxDomainName.Text, ResHelper.GetString("Administration-Site_Edit.RequiresDomainName")).Result;

        if (result == "")
        {
            SiteInfo si = null;
            // Finds whether edited site code name is unique
            si = SiteInfoProvider.GetSiteInfo(TextBoxCodeName.Text);

            if ((si == null) || (si.SiteID == siteId))
            {
                // Update SiteInfo
                if (SaveSite())
                {
                    // Display save information
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Administration-Site_Edit.SiteExists");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }

    }

    /// <summary>
    /// Save edited site.
    /// </summary>
    private bool SaveSite()
    {
        // Correct domain name and return it to textbox
        TextBoxDomainName.Text = CorrectDomainName(TextBoxDomainName.Text);
        // Get SiteInfo with the given siteID
        SiteInfo currentSiteInfo = new SiteInfo();
        if (siteId > 0)
        {
            try
            {
                // Update SiteInfo parameters
                currentSiteInfo.SiteName = TextBoxCodeName.Text;
                currentSiteInfo.Description = TextBoxDescription.Text;
                currentSiteInfo.DisplayName = TextBoxDisplayName.Text;
                currentSiteInfo.DomainName = TextBoxDomainName.Text;
                currentSiteInfo.DefaultVisitorCulture = drpVisitorCulture.SelectedItem.Value;
                currentSiteInfo.SiteID = siteId;

                if (drpCssStyle.SelectedItem.Value == "-1")
                {
                    currentSiteInfo.SiteDefaultStylesheetID = 0;
                }
                else
                {
                    currentSiteInfo.SiteDefaultStylesheetID = Convert.ToInt32(drpCssStyle.SelectedValue);
                }

                if (drpEditorStyle.SelectedItem.Value == "-1")
                {
                    currentSiteInfo.SiteDefaultEditorStylesheet = 0;
                }
                else
                {
                    currentSiteInfo.SiteDefaultEditorStylesheet = Convert.ToInt32(drpEditorStyle.SelectedValue);
                }

                SiteStatusEnum mStatus = SiteStatusEnum.Stopped;
                SiteInfo si = SiteInfoProvider.GetSiteInfo(siteId);
                if (si != null)
                {
                    // Get current site status
                    mStatus = si.Status;
                    // Stop the site
                    SiteInfoProvider.StopSite(si.SiteName);
                    currentSiteInfo.Status = SiteStatusEnum.Stopped;
                }

                // Save SiteInfo
                SiteInfoProvider.SetSiteInfo(currentSiteInfo);

                if (mStatus != SiteStatusEnum.Stopped)
                {
                    // Run current site
                    SiteInfoProvider.RunSite(currentSiteInfo.SiteName);
                }
            }
            catch (RunningSiteException exc)
            {
                lblError.Visible = true;
                lblError.Text = exc.Message;
            }
            return true;
        }
        else
        {
            return false;
        }
    }

    /// <summary>
    /// Removes white characters from the beginning and end. Also removes protocol declarations and 'www.' string from begin.
    /// </summary>
    /// <param name="domainName">String to correct</param>
    /// <returns>Corrected string</returns>
    protected string CorrectDomainName(string domainName)
    {
        string result = domainName;
        result = result.Trim();
        string lowcaseResult = result.ToLower();

        while (lowcaseResult.IndexOf("https://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("https://"), 8);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("https://"), 8);
        }

        while (lowcaseResult.IndexOf("http://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("http://"), 7);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("http://"), 7);
        }

        while (lowcaseResult.StartsWith("www.", true, null))
        {
            result = result.Remove(lowcaseResult.IndexOf("www."), 4);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("www."), 4);
        }

        return result;
    }

    /// <summary>
    /// Fills dropdownlist with css stylesheets for specified site.
    /// </summary>
    /// <param name="siteName">Site name.</param>
    protected void FillCssStylesheetDrops(string siteName)
    {
        // add default item to the Editor CSS stylesheet drop down list
        ListItem item = new ListItem();
        item.Text = ResHelper.GetString("Administration-Site_Edit.SiteStyleSheet");
        item.Value = "-1";
        drpEditorStyle.Items.Add(item);

        // add default item to the CssStylesheet drop down list
        item = new ListItem();
        item.Text = ResHelper.GetString("Administration-Site_Edit.NoneSiteStyleSheet");
        item.Value = "-1";
        drpCssStyle.Items.Add(item);

        DataSet ds = null;
        ListItem li = null;

        // Fill drop down list for site stylesheets
        ds = CssStylesheetInfoProvider.GetCssStylesheets(siteName);
        if ((ds != null) && (ds.Tables.Count > 0) && (ds.Tables[0].Rows.Count > 0))
        {
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                li = new ListItem();
                li.Text = dr["StylesheetDisplayName"].ToString();
                li.Value = dr["StylesheetID"].ToString();
                drpCssStyle.Items.Add(li);
            }
        }

        // fill drop down list for editor stylesheets
        ds = CssStylesheetInfoProvider.GetAllCssStylesheets();
        if ((ds != null) && (ds.Tables.Count > 0) && (ds.Tables[0].Rows.Count > 0))
        {
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                li = new ListItem();
                li.Text = dr["StylesheetDisplayName"].ToString();
                li.Value = dr["StylesheetID"].ToString();
                drpEditorStyle.Items.Add(li);
            }
        }
    }
}
